Class: Aws::Amplify::Types::CreateDomainAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-amplify/types.rb

Overview

The request structure for the create domain association request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_idString

The unique ID for an Amplify app.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#auto_sub_domain_creation_patternsArray<String>

Sets the branch patterns for automatic subdomain creation.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#auto_sub_domain_iam_roleString

The required AWS Identity and Access Management (IAM) service role for the Amazon Resource Name (ARN) for automatically creating subdomains.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_settingsTypes::CertificateSettings

The type of SSL/TLS certificate to use for your custom domain. If you don't specify a certificate type, Amplify uses the default certificate that it provisions and manages for you.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name for the domain association.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#enable_auto_sub_domainBoolean

Enables the automated creation of subdomains for branches.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sub_domain_settingsArray<Types::SubDomainSetting>

The setting for the subdomain.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/aws-sdk-amplify/types.rb', line 1200

class CreateDomainAssociationRequest < Struct.new(
  :app_id,
  :domain_name,
  :enable_auto_sub_domain,
  :sub_domain_settings,
  :auto_sub_domain_creation_patterns,
  :auto_sub_domain_iam_role,
  :certificate_settings)
  SENSITIVE = []
  include Aws::Structure
end