Class: Aws::Amplify::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Amplify::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-amplify/client.rb,
sig/client.rbs
Overview
An API client for Amplify. To construct a client, you need to configure a :region and :credentials.
client = Aws::Amplify::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAppResponseSuccess, _CreateBackendEnvironmentResponseSuccess, _CreateBranchResponseSuccess, _CreateDeploymentResponseSuccess, _CreateDomainAssociationResponseSuccess, _CreateWebhookResponseSuccess, _DeleteAppResponseSuccess, _DeleteBackendEnvironmentResponseSuccess, _DeleteBranchResponseSuccess, _DeleteDomainAssociationResponseSuccess, _DeleteJobResponseSuccess, _DeleteWebhookResponseSuccess, _GenerateAccessLogsResponseSuccess, _GetAppResponseSuccess, _GetArtifactUrlResponseSuccess, _GetBackendEnvironmentResponseSuccess, _GetBranchResponseSuccess, _GetDomainAssociationResponseSuccess, _GetJobResponseSuccess, _GetWebhookResponseSuccess, _ListAppsResponseSuccess, _ListArtifactsResponseSuccess, _ListBackendEnvironmentsResponseSuccess, _ListBranchesResponseSuccess, _ListDomainAssociationsResponseSuccess, _ListJobsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWebhooksResponseSuccess, _StartDeploymentResponseSuccess, _StartJobResponseSuccess, _StopJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAppResponseSuccess, _UpdateBranchResponseSuccess, _UpdateDomainAssociationResponseSuccess, _UpdateWebhookResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app(params = {}) ⇒ Types::CreateAppResult
Creates a new Amplify app.
-
#create_backend_environment(params = {}) ⇒ Types::CreateBackendEnvironmentResult
Creates a new backend environment for an Amplify app.
-
#create_branch(params = {}) ⇒ Types::CreateBranchResult
Creates a new branch for an Amplify app.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResult
Creates a deployment for a manually deployed Amplify app.
-
#create_domain_association(params = {}) ⇒ Types::CreateDomainAssociationResult
Creates a new domain association for an Amplify app.
-
#create_webhook(params = {}) ⇒ Types::CreateWebhookResult
Creates a new webhook on an Amplify app.
-
#delete_app(params = {}) ⇒ Types::DeleteAppResult
Deletes an existing Amplify app specified by an app ID.
-
#delete_backend_environment(params = {}) ⇒ Types::DeleteBackendEnvironmentResult
Deletes a backend environment for an Amplify app.
-
#delete_branch(params = {}) ⇒ Types::DeleteBranchResult
Deletes a branch for an Amplify app.
-
#delete_domain_association(params = {}) ⇒ Types::DeleteDomainAssociationResult
Deletes a domain association for an Amplify app.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResult
Deletes a job for a branch of an Amplify app.
-
#delete_webhook(params = {}) ⇒ Types::DeleteWebhookResult
Deletes a webhook.
-
#generate_access_logs(params = {}) ⇒ Types::GenerateAccessLogsResult
Returns the website access logs for a specific time range using a presigned URL.
-
#get_app(params = {}) ⇒ Types::GetAppResult
Returns an existing Amplify app specified by an app ID.
-
#get_artifact_url(params = {}) ⇒ Types::GetArtifactUrlResult
Returns the artifact info that corresponds to an artifact id.
-
#get_backend_environment(params = {}) ⇒ Types::GetBackendEnvironmentResult
Returns a backend environment for an Amplify app.
-
#get_branch(params = {}) ⇒ Types::GetBranchResult
Returns a branch for an Amplify app.
-
#get_domain_association(params = {}) ⇒ Types::GetDomainAssociationResult
Returns the domain information for an Amplify app.
-
#get_job(params = {}) ⇒ Types::GetJobResult
Returns a job for a branch of an Amplify app.
-
#get_webhook(params = {}) ⇒ Types::GetWebhookResult
Returns the webhook information that corresponds to a specified webhook ID.
-
#list_apps(params = {}) ⇒ Types::ListAppsResult
Returns a list of the existing Amplify apps.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Returns a list of end-to-end testing artifacts for a specified app, branch, and job.
-
#list_backend_environments(params = {}) ⇒ Types::ListBackendEnvironmentsResult
Lists the backend environments for an Amplify app.
-
#list_branches(params = {}) ⇒ Types::ListBranchesResult
Lists the branches of an Amplify app.
-
#list_domain_associations(params = {}) ⇒ Types::ListDomainAssociationsResult
Returns the domain associations for an Amplify app.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Lists the jobs for a branch of an Amplify app.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksResult
Returns a list of webhooks for an Amplify app.
-
#start_deployment(params = {}) ⇒ Types::StartDeploymentResult
Starts a deployment for a manually deployed app.
-
#start_job(params = {}) ⇒ Types::StartJobResult
Starts a new job for a branch of an Amplify app.
-
#stop_job(params = {}) ⇒ Types::StopJobResult
Stops a job that is in progress for a branch of an Amplify app.
-
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
-
#update_app(params = {}) ⇒ Types::UpdateAppResult
Updates an existing Amplify app.
-
#update_branch(params = {}) ⇒ Types::UpdateBranchResult
Updates a branch for an Amplify app.
-
#update_domain_association(params = {}) ⇒ Types::UpdateDomainAssociationResult
Creates a new domain association for an Amplify app.
-
#update_webhook(params = {}) ⇒ Types::UpdateWebhookResult
Updates a webhook.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-amplify/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3172 3173 3174 |
# File 'lib/aws-sdk-amplify/client.rb', line 3172 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3175 3176 3177 |
# File 'lib/aws-sdk-amplify/client.rb', line 3175 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 |
# File 'lib/aws-sdk-amplify/client.rb', line 3145 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Amplify') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-amplify' context[:gem_version] = '1.104.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app(params = {}) ⇒ Types::CreateAppResult
Creates a new Amplify app.
86 |
# File 'sig/client.rbs', line 86
def create_app: (
|
#create_backend_environment(params = {}) ⇒ Types::CreateBackendEnvironmentResult
Creates a new backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app's backend infrastructure using Typescript code.
128 |
# File 'sig/client.rbs', line 128
def create_backend_environment: (
|
#create_branch(params = {}) ⇒ Types::CreateBranchResult
Creates a new branch for an Amplify app.
141 |
# File 'sig/client.rbs', line 141
def create_branch: (
|
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResult
Creates a deployment for a manually deployed Amplify app. Manually deployed apps are not connected to a Git repository.
The maximum duration between the CreateDeployment call and the
StartDeployment call cannot exceed 8 hours. If the duration exceeds
8 hours, the StartDeployment call and the associated Job will
fail.
175 |
# File 'sig/client.rbs', line 175
def create_deployment: (
|
#create_domain_association(params = {}) ⇒ Types::CreateDomainAssociationResult
Creates a new domain association for an Amplify app. This action associates a custom domain with the Amplify app
187 |
# File 'sig/client.rbs', line 187
def create_domain_association: (
|
#create_webhook(params = {}) ⇒ Types::CreateWebhookResult
Creates a new webhook on an Amplify app.
211 |
# File 'sig/client.rbs', line 211
def create_webhook: (
|
#delete_app(params = {}) ⇒ Types::DeleteAppResult
Deletes an existing Amplify app specified by an app ID.
223 |
# File 'sig/client.rbs', line 223
def delete_app: (
|
#delete_backend_environment(params = {}) ⇒ Types::DeleteBackendEnvironmentResult
Deletes a backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app's backend infrastructure using Typescript code.
233 |
# File 'sig/client.rbs', line 233
def delete_backend_environment: (
|
#delete_branch(params = {}) ⇒ Types::DeleteBranchResult
Deletes a branch for an Amplify app.
244 |
# File 'sig/client.rbs', line 244
def delete_branch: (
|
#delete_domain_association(params = {}) ⇒ Types::DeleteDomainAssociationResult
Deletes a domain association for an Amplify app.
255 |
# File 'sig/client.rbs', line 255
def delete_domain_association: (
|
#delete_job(params = {}) ⇒ Types::DeleteJobResult
Deletes a job for a branch of an Amplify app.
266 |
# File 'sig/client.rbs', line 266
def delete_job: (
|
#delete_webhook(params = {}) ⇒ Types::DeleteWebhookResult
Deletes a webhook.
278 |
# File 'sig/client.rbs', line 278
def delete_webhook: (
|
#generate_access_logs(params = {}) ⇒ Types::GenerateAccessLogsResult
Returns the website access logs for a specific time range using a presigned URL.
288 |
# File 'sig/client.rbs', line 288
def generate_access_logs: (
|
#get_app(params = {}) ⇒ Types::GetAppResult
Returns an existing Amplify app specified by an app ID.
301 |
# File 'sig/client.rbs', line 301
def get_app: (
|
#get_artifact_url(params = {}) ⇒ Types::GetArtifactUrlResult
Returns the artifact info that corresponds to an artifact id.
312 |
# File 'sig/client.rbs', line 312
def get_artifact_url: (
|
#get_backend_environment(params = {}) ⇒ Types::GetBackendEnvironmentResult
Returns a backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app's backend infrastructure using Typescript code.
322 |
# File 'sig/client.rbs', line 322
def get_backend_environment: (
|
#get_branch(params = {}) ⇒ Types::GetBranchResult
Returns a branch for an Amplify app.
333 |
# File 'sig/client.rbs', line 333
def get_branch: (
|
#get_domain_association(params = {}) ⇒ Types::GetDomainAssociationResult
Returns the domain information for an Amplify app.
344 |
# File 'sig/client.rbs', line 344
def get_domain_association: (
|
#get_job(params = {}) ⇒ Types::GetJobResult
Returns a job for a branch of an Amplify app.
355 |
# File 'sig/client.rbs', line 355
def get_job: (
|
#get_webhook(params = {}) ⇒ Types::GetWebhookResult
Returns the webhook information that corresponds to a specified webhook ID.
367 |
# File 'sig/client.rbs', line 367
def get_webhook: (
|
#list_apps(params = {}) ⇒ Types::ListAppsResult
Returns a list of the existing Amplify apps.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
378 |
# File 'sig/client.rbs', line 378
def list_apps: (
|
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Returns a list of end-to-end testing artifacts for a specified app, branch, and job.
To return the build artifacts, use the GetJob API.
For more information about Amplify testing support, see Setting up end-to-end Cypress tests for your Amplify application in the Amplify Hosting User Guide.
390 |
# File 'sig/client.rbs', line 390
def list_artifacts: (
|
#list_backend_environments(params = {}) ⇒ Types::ListBackendEnvironmentsResult
Lists the backend environments for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app's backend infrastructure using Typescript code.
405 |
# File 'sig/client.rbs', line 405
def list_backend_environments: (
|
#list_branches(params = {}) ⇒ Types::ListBranchesResult
Lists the branches of an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
419 |
# File 'sig/client.rbs', line 419
def list_branches: (
|
#list_domain_associations(params = {}) ⇒ Types::ListDomainAssociationsResult
Returns the domain associations for an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
432 |
# File 'sig/client.rbs', line 432
def list_domain_associations: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Lists the jobs for a branch of an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
445 |
# File 'sig/client.rbs', line 445
def list_jobs: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
458 |
# File 'sig/client.rbs', line 458
def list_tags_for_resource: (
|
#list_webhooks(params = {}) ⇒ Types::ListWebhooksResult
Returns a list of webhooks for an Amplify app.
469 |
# File 'sig/client.rbs', line 469
def list_webhooks: (
|
#start_deployment(params = {}) ⇒ Types::StartDeploymentResult
Starts a deployment for a manually deployed app. Manually deployed apps are not connected to a Git repository.
The maximum duration between the CreateDeployment call and the
StartDeployment call cannot exceed 8 hours. If the duration exceeds
8 hours, the StartDeployment call and the associated Job will
fail.
481 |
# File 'sig/client.rbs', line 481
def start_deployment: (
|
#start_job(params = {}) ⇒ Types::StartJobResult
Starts a new job for a branch of an Amplify app.
495 |
# File 'sig/client.rbs', line 495
def start_job: (
|
#stop_job(params = {}) ⇒ Types::StopJobResult
Stops a job that is in progress for a branch of an Amplify app.
512 |
# File 'sig/client.rbs', line 512
def stop_job: (
|
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
523 |
# File 'sig/client.rbs', line 523
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
533 |
# File 'sig/client.rbs', line 533
def untag_resource: (
|
#update_app(params = {}) ⇒ Types::UpdateAppResult
Updates an existing Amplify app.
544 |
# File 'sig/client.rbs', line 544
def update_app: (
|
#update_branch(params = {}) ⇒ Types::UpdateBranchResult
Updates a branch for an Amplify app.
586 |
# File 'sig/client.rbs', line 586
def update_branch: (
|
#update_domain_association(params = {}) ⇒ Types::UpdateDomainAssociationResult
Creates a new domain association for an Amplify app.
617 |
# File 'sig/client.rbs', line 617
def update_domain_association: (
|
#update_webhook(params = {}) ⇒ Types::UpdateWebhookResult
Updates a webhook.
641 |
# File 'sig/client.rbs', line 641
def update_webhook: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3165 3166 3167 |
# File 'lib/aws-sdk-amplify/client.rb', line 3165 def waiter_names [] end |