Class: Aws::Amplify::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Amplify::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-amplify/client.rb
Overview
An API client for Amplify. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Amplify::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app(params = {}) ⇒ Types::CreateAppResult
Creates a new Amplify app.
-
#create_backend_environment(params = {}) ⇒ Types::CreateBackendEnvironmentResult
Creates a new backend environment for an Amplify app.
-
#create_branch(params = {}) ⇒ Types::CreateBranchResult
Creates a new branch for an Amplify app.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResult
Creates a deployment for a manually deployed Amplify app.
-
#create_domain_association(params = {}) ⇒ Types::CreateDomainAssociationResult
Creates a new domain association for an Amplify app.
-
#create_webhook(params = {}) ⇒ Types::CreateWebhookResult
Creates a new webhook on an Amplify app.
-
#delete_app(params = {}) ⇒ Types::DeleteAppResult
Deletes an existing Amplify app specified by an app ID.
-
#delete_backend_environment(params = {}) ⇒ Types::DeleteBackendEnvironmentResult
Deletes a backend environment for an Amplify app.
-
#delete_branch(params = {}) ⇒ Types::DeleteBranchResult
Deletes a branch for an Amplify app.
-
#delete_domain_association(params = {}) ⇒ Types::DeleteDomainAssociationResult
Deletes a domain association for an Amplify app.
-
#delete_job(params = {}) ⇒ Types::DeleteJobResult
Deletes a job for a branch of an Amplify app.
-
#delete_webhook(params = {}) ⇒ Types::DeleteWebhookResult
Deletes a webhook.
-
#generate_access_logs(params = {}) ⇒ Types::GenerateAccessLogsResult
Returns the website access logs for a specific time range using a presigned URL.
-
#get_app(params = {}) ⇒ Types::GetAppResult
Returns an existing Amplify app specified by an app ID.
-
#get_artifact_url(params = {}) ⇒ Types::GetArtifactUrlResult
Returns the artifact info that corresponds to an artifact id.
-
#get_backend_environment(params = {}) ⇒ Types::GetBackendEnvironmentResult
Returns a backend environment for an Amplify app.
-
#get_branch(params = {}) ⇒ Types::GetBranchResult
Returns a branch for an Amplify app.
-
#get_domain_association(params = {}) ⇒ Types::GetDomainAssociationResult
Returns the domain information for an Amplify app.
-
#get_job(params = {}) ⇒ Types::GetJobResult
Returns a job for a branch of an Amplify app.
-
#get_webhook(params = {}) ⇒ Types::GetWebhookResult
Returns the webhook information that corresponds to a specified webhook ID.
-
#list_apps(params = {}) ⇒ Types::ListAppsResult
Returns a list of the existing Amplify apps.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Returns a list of end-to-end testing artifacts for a specified app, branch, and job.
-
#list_backend_environments(params = {}) ⇒ Types::ListBackendEnvironmentsResult
Lists the backend environments for an Amplify app.
-
#list_branches(params = {}) ⇒ Types::ListBranchesResult
Lists the branches of an Amplify app.
-
#list_domain_associations(params = {}) ⇒ Types::ListDomainAssociationsResult
Returns the domain associations for an Amplify app.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Lists the jobs for a branch of an Amplify app.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksResult
Returns a list of webhooks for an Amplify app.
-
#start_deployment(params = {}) ⇒ Types::StartDeploymentResult
Starts a deployment for a manually deployed app.
-
#start_job(params = {}) ⇒ Types::StartJobResult
Starts a new job for a branch of an Amplify app.
-
#stop_job(params = {}) ⇒ Types::StopJobResult
Stops a job that is in progress for a branch of an Amplify app.
-
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
-
#update_app(params = {}) ⇒ Types::UpdateAppResult
Updates an existing Amplify app.
-
#update_branch(params = {}) ⇒ Types::UpdateBranchResult
Updates a branch for an Amplify app.
-
#update_domain_association(params = {}) ⇒ Types::UpdateDomainAssociationResult
Creates a new domain association for an Amplify app.
-
#update_webhook(params = {}) ⇒ Types::UpdateWebhookResult
Updates a webhook.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-amplify/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3172 3173 3174 |
# File 'lib/aws-sdk-amplify/client.rb', line 3172 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3175 3176 3177 |
# File 'lib/aws-sdk-amplify/client.rb', line 3175 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 |
# File 'lib/aws-sdk-amplify/client.rb', line 3145 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Amplify') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-amplify' context[:gem_version] = '1.102.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app(params = {}) ⇒ Types::CreateAppResult
Creates a new Amplify app.
737 738 739 740 |
# File 'lib/aws-sdk-amplify/client.rb', line 737 def create_app(params = {}, = {}) req = build_request(:create_app, params) req.send_request() end |
#create_backend_environment(params = {}) ⇒ Types::CreateBackendEnvironmentResult
Creates a new backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app’s backend infrastructure using Typescript code.
788 789 790 791 |
# File 'lib/aws-sdk-amplify/client.rb', line 788 def create_backend_environment(params = {}, = {}) req = build_request(:create_backend_environment, params) req.send_request() end |
#create_branch(params = {}) ⇒ Types::CreateBranchResult
Creates a new branch for an Amplify app.
975 976 977 978 |
# File 'lib/aws-sdk-amplify/client.rb', line 975 def create_branch(params = {}, = {}) req = build_request(:create_branch, params) req.send_request() end |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentResult
Creates a deployment for a manually deployed Amplify app. Manually deployed apps are not connected to a Git repository.
The maximum duration between the ‘CreateDeployment` call and the `StartDeployment` call cannot exceed 8 hours. If the duration exceeds 8 hours, the `StartDeployment` call and the associated `Job` will fail.
1027 1028 1029 1030 |
# File 'lib/aws-sdk-amplify/client.rb', line 1027 def create_deployment(params = {}, = {}) req = build_request(:create_deployment, params) req.send_request() end |
#create_domain_association(params = {}) ⇒ Types::CreateDomainAssociationResult
Creates a new domain association for an Amplify app. This action associates a custom domain with the Amplify app
1108 1109 1110 1111 |
# File 'lib/aws-sdk-amplify/client.rb', line 1108 def create_domain_association(params = {}, = {}) req = build_request(:create_domain_association, params) req.send_request() end |
#create_webhook(params = {}) ⇒ Types::CreateWebhookResult
Creates a new webhook on an Amplify app.
1151 1152 1153 1154 |
# File 'lib/aws-sdk-amplify/client.rb', line 1151 def create_webhook(params = {}, = {}) req = build_request(:create_webhook, params) req.send_request() end |
#delete_app(params = {}) ⇒ Types::DeleteAppResult
Deletes an existing Amplify app specified by an app ID.
1229 1230 1231 1232 |
# File 'lib/aws-sdk-amplify/client.rb', line 1229 def delete_app(params = {}, = {}) req = build_request(:delete_app, params) req.send_request() end |
#delete_backend_environment(params = {}) ⇒ Types::DeleteBackendEnvironmentResult
Deletes a backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app’s backend infrastructure using Typescript code.
1272 1273 1274 1275 |
# File 'lib/aws-sdk-amplify/client.rb', line 1272 def delete_backend_environment(params = {}, = {}) req = build_request(:delete_backend_environment, params) req.send_request() end |
#delete_branch(params = {}) ⇒ Types::DeleteBranchResult
Deletes a branch for an Amplify app.
1337 1338 1339 1340 |
# File 'lib/aws-sdk-amplify/client.rb', line 1337 def delete_branch(params = {}, = {}) req = build_request(:delete_branch, params) req.send_request() end |
#delete_domain_association(params = {}) ⇒ Types::DeleteDomainAssociationResult
Deletes a domain association for an Amplify app.
1386 1387 1388 1389 |
# File 'lib/aws-sdk-amplify/client.rb', line 1386 def delete_domain_association(params = {}, = {}) req = build_request(:delete_domain_association, params) req.send_request() end |
#delete_job(params = {}) ⇒ Types::DeleteJobResult
Deletes a job for a branch of an Amplify app.
1432 1433 1434 1435 |
# File 'lib/aws-sdk-amplify/client.rb', line 1432 def delete_job(params = {}, = {}) req = build_request(:delete_job, params) req.send_request() end |
#delete_webhook(params = {}) ⇒ Types::DeleteWebhookResult
Deletes a webhook.
1467 1468 1469 1470 |
# File 'lib/aws-sdk-amplify/client.rb', line 1467 def delete_webhook(params = {}, = {}) req = build_request(:delete_webhook, params) req.send_request() end |
#generate_access_logs(params = {}) ⇒ Types::GenerateAccessLogsResult
Returns the website access logs for a specific time range using a presigned URL.
1510 1511 1512 1513 |
# File 'lib/aws-sdk-amplify/client.rb', line 1510 def generate_access_logs(params = {}, = {}) req = build_request(:generate_access_logs, params) req.send_request() end |
#get_app(params = {}) ⇒ Types::GetAppResult
Returns an existing Amplify app specified by an app ID.
1588 1589 1590 1591 |
# File 'lib/aws-sdk-amplify/client.rb', line 1588 def get_app(params = {}, = {}) req = build_request(:get_app, params) req.send_request() end |
#get_artifact_url(params = {}) ⇒ Types::GetArtifactUrlResult
Returns the artifact info that corresponds to an artifact id.
1618 1619 1620 1621 |
# File 'lib/aws-sdk-amplify/client.rb', line 1618 def get_artifact_url(params = {}, = {}) req = build_request(:get_artifact_url, params) req.send_request() end |
#get_backend_environment(params = {}) ⇒ Types::GetBackendEnvironmentResult
Returns a backend environment for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app’s backend infrastructure using Typescript code.
1661 1662 1663 1664 |
# File 'lib/aws-sdk-amplify/client.rb', line 1661 def get_backend_environment(params = {}, = {}) req = build_request(:get_backend_environment, params) req.send_request() end |
#get_branch(params = {}) ⇒ Types::GetBranchResult
Returns a branch for an Amplify app.
1726 1727 1728 1729 |
# File 'lib/aws-sdk-amplify/client.rb', line 1726 def get_branch(params = {}, = {}) req = build_request(:get_branch, params) req.send_request() end |
#get_domain_association(params = {}) ⇒ Types::GetDomainAssociationResult
Returns the domain information for an Amplify app.
1775 1776 1777 1778 |
# File 'lib/aws-sdk-amplify/client.rb', line 1775 def get_domain_association(params = {}, = {}) req = build_request(:get_domain_association, params) req.send_request() end |
#get_job(params = {}) ⇒ Types::GetJobResult
Returns a job for a branch of an Amplify app.
1834 1835 1836 1837 |
# File 'lib/aws-sdk-amplify/client.rb', line 1834 def get_job(params = {}, = {}) req = build_request(:get_job, params) req.send_request() end |
#get_webhook(params = {}) ⇒ Types::GetWebhookResult
Returns the webhook information that corresponds to a specified webhook ID.
1870 1871 1872 1873 |
# File 'lib/aws-sdk-amplify/client.rb', line 1870 def get_webhook(params = {}, = {}) req = build_request(:get_webhook, params) req.send_request() end |
#list_apps(params = {}) ⇒ Types::ListAppsResult
Returns a list of the existing Amplify apps.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1958 1959 1960 1961 |
# File 'lib/aws-sdk-amplify/client.rb', line 1958 def list_apps(params = {}, = {}) req = build_request(:list_apps, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Returns a list of end-to-end testing artifacts for a specified app, branch, and job.
To return the build artifacts, use the [GetJob] API.
For more information about Amplify testing support, see [Setting up end-to-end Cypress tests for your Amplify application] in the *Amplify Hosting User Guide*.
[1]: docs.aws.amazon.com/amplify/latest/APIReference/API_GetJob.html [2]: docs.aws.amazon.com/amplify/latest/userguide/running-tests.html
2020 2021 2022 2023 |
# File 'lib/aws-sdk-amplify/client.rb', line 2020 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_backend_environments(params = {}) ⇒ Types::ListBackendEnvironmentsResult
Lists the backend environments for an Amplify app.
This API is available only to Amplify Gen 1 applications where the backend is created using Amplify Studio or the Amplify command line interface (CLI). This API isn’t available to Amplify Gen 2 applications. When you deploy an application with Amplify Gen 2, you provision the app’s backend infrastructure using Typescript code.
2076 2077 2078 2079 |
# File 'lib/aws-sdk-amplify/client.rb', line 2076 def list_backend_environments(params = {}, = {}) req = build_request(:list_backend_environments, params) req.send_request() end |
#list_branches(params = {}) ⇒ Types::ListBranchesResult
Lists the branches of an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2152 2153 2154 2155 |
# File 'lib/aws-sdk-amplify/client.rb', line 2152 def list_branches(params = {}, = {}) req = build_request(:list_branches, params) req.send_request() end |
#list_domain_associations(params = {}) ⇒ Types::ListDomainAssociationsResult
Returns the domain associations for an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2212 2213 2214 2215 |
# File 'lib/aws-sdk-amplify/client.rb', line 2212 def list_domain_associations(params = {}, = {}) req = build_request(:list_domain_associations, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Lists the jobs for a branch of an Amplify app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2269 2270 2271 2272 |
# File 'lib/aws-sdk-amplify/client.rb', line 2269 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified Amazon Resource Name (ARN).
2298 2299 2300 2301 |
# File 'lib/aws-sdk-amplify/client.rb', line 2298 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_webhooks(params = {}) ⇒ Types::ListWebhooksResult
Returns a list of webhooks for an Amplify app.
2346 2347 2348 2349 |
# File 'lib/aws-sdk-amplify/client.rb', line 2346 def list_webhooks(params = {}, = {}) req = build_request(:list_webhooks, params) req.send_request() end |
#start_deployment(params = {}) ⇒ Types::StartDeploymentResult
Starts a deployment for a manually deployed app. Manually deployed apps are not connected to a Git repository.
The maximum duration between the ‘CreateDeployment` call and the `StartDeployment` call cannot exceed 8 hours. If the duration exceeds 8 hours, the `StartDeployment` call and the associated `Job` will fail.
2413 2414 2415 2416 |
# File 'lib/aws-sdk-amplify/client.rb', line 2413 def start_deployment(params = {}, = {}) req = build_request(:start_deployment, params) req.send_request() end |
#start_job(params = {}) ⇒ Types::StartJobResult
Starts a new job for a branch of an Amplify app.
2485 2486 2487 2488 |
# File 'lib/aws-sdk-amplify/client.rb', line 2485 def start_job(params = {}, = {}) req = build_request(:start_job, params) req.send_request() end |
#stop_job(params = {}) ⇒ Types::StopJobResult
Stops a job that is in progress for a branch of an Amplify app.
2531 2532 2533 2534 |
# File 'lib/aws-sdk-amplify/client.rb', line 2531 def stop_job(params = {}, = {}) req = build_request(:stop_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags the resource with a tag key and value.
2559 2560 2561 2562 |
# File 'lib/aws-sdk-amplify/client.rb', line 2559 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource with a specified Amazon Resource Name (ARN).
2585 2586 2587 2588 |
# File 'lib/aws-sdk-amplify/client.rb', line 2585 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_app(params = {}) ⇒ Types::UpdateAppResult
Updates an existing Amplify app.
2834 2835 2836 2837 |
# File 'lib/aws-sdk-amplify/client.rb', line 2834 def update_app(params = {}, = {}) req = build_request(:update_app, params) req.send_request() end |
#update_branch(params = {}) ⇒ Types::UpdateBranchResult
Updates a branch for an Amplify app.
3015 3016 3017 3018 |
# File 'lib/aws-sdk-amplify/client.rb', line 3015 def update_branch(params = {}, = {}) req = build_request(:update_branch, params) req.send_request() end |
#update_domain_association(params = {}) ⇒ Types::UpdateDomainAssociationResult
Creates a new domain association for an Amplify app.
3093 3094 3095 3096 |
# File 'lib/aws-sdk-amplify/client.rb', line 3093 def update_domain_association(params = {}, = {}) req = build_request(:update_domain_association, params) req.send_request() end |
#update_webhook(params = {}) ⇒ Types::UpdateWebhookResult
Updates a webhook.
3136 3137 3138 3139 |
# File 'lib/aws-sdk-amplify/client.rb', line 3136 def update_webhook(params = {}, = {}) req = build_request(:update_webhook, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3165 3166 3167 |
# File 'lib/aws-sdk-amplify/client.rb', line 3165 def waiter_names [] end |